@@ -1,10 +1,4 @@
 package Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp;
-{
-  $Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp::VERSION = '0.1.5';
-}
-{
-  $Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp::DIST = 'Catalyst-Plugin-ErrorCatcher-ActiveMQ-Stomp';
-}
 
 use Moose;
 use Net::Stomp;
@@ -18,14 +12,11 @@ use Fcntl qw(:flock);
 
 =head1 NAME
 
-Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp - Plugin for ErrorCatcher to throw exceptions over ActiveMQ using Stomp
-
-=head1 VERSION
-
-version 0.1.5
+Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp - The great new Catalyst::Plugin::ErrorCatcher::ActiveMQ::Stomp!
 
 =cut
 
+use version; our $VERSION = qv(0.1.0)->numify;
 
 
 class_type 'Data::Serializer';
@@ -170,7 +161,6 @@ sub _next_test_filename {
 
     # Get a lock on "$dir/.lock" to avoid prove -j issues
     my $lock;
-    mkdir $dir;
     open($lock, ">", "$dir/.lock") or die "Unable to open lock file $dir/.lock";
     flock($lock, LOCK_EX) or die "Cannot lock ActiveMQ dump dir";
 
